@@ -81,9 +81,12 @@ class CopyHelper(OgrUtils):
                 feat_out.SetField(out_lyr_defn.GetFieldDefn(i).GetNameRef(), value)
 
             geom = feat.GetGeometryRef()
-            feat_out.SetGeometry(geom.Clone())
-            # Add new feature to output Layer
-            out_lyr.CreateFeature(feat_out)
+            if geom:
+                feat_out.SetGeometry(geom.Clone())
+                # Add new feature to output Layer
+                out_lyr.CreateFeature(feat_out)
+            else:
+                print 'WARNING. NULL geometry found! Will be skipped.'
 
         # create a spatial index on the output table
         table_name = os.path.splitext(os.path.basename(out_shp))[0]
